# Credits

## Main Developer

* Veronica Berglyd Olsen

## Contributors

* Early Concept: Marian Lückhof
* Internationalisation: Bruno Meneguello
* Setup and Packaging: Rachel Powers

For other contributions, see the project's [Contributors](https://github.com/vkbo/novelWriter/graphs/contributors) page.

## Artwork

The artwork on the Welcome dialog was created by Louis Durrant.

## Translations

The default language is English (UK) with English (US) as an option. These are the original
translators for the languages currently available:

* **Czech:** Tomáš Zmek (perteus)
* **Dutch:** Martijn van der Kleijn (mvdkleijn)
* **French:** Jan Lüdke (jyhelle)
* **German:** Myian (HeyMyian)
* **Italian:** Riccardo Mangili
* **Japanese:** hebekeg
* **Latin American Spanish:** Tommy Marplatt (tmarplatt)
* **Norwegian:** Veronica Berglyd Olsen (vkbo)
* **Polish:** Anna Maria Polak (Nauthiz)
* **Portuguese:** Bruno Meneguello (bkmeneguello)
* **Russian:** Konstantin Tan (k1kimosha)
* **Simplified Chinese:** Qianzhi Long (longqzh)

Additional larger translation contributions:

* **French:** Albert Aribaud (aaribaud)
* **Portuguese:** Oli Maia (olimaia)

Translations of the documentation:

* **French:** Jean-Michel Heras (Karduin)

Translations are managed on [Crowdin](https://crowdin.com/project/novelwriter), and more
contributions are listed on the project's Members page.

## Libraries

The following libraries are dependencies of novelWriter:

* **Qt6** by Qt Company
* **PyQt6** by Riverbank Computing
* **Enchant** by Dom Lachowicz
* **PyEnchant** by Dimitri Merejkowsky

## Icon Themes

The default icon theme is a subset of icons from:

* **Material Symbols** by Google Inc (Apache 2.0)

Additional icon themes may or may not be bundled with novelWriter, depending on license
constraints. These themes include a subset of icons from:

* **Font Awesome** by Fonticons Inc (CC BY 4.0)
* **Remix** by RemixIcon (Apache 2.0 w/non-free clause)

## Colour Themes

Colour themes included with novelWriter were adapted from the following sources:

* **Aura** themes by Dalton Menezes
* **B2T** themes by Bram de Haan
* **B4T** themes by Bram de Haan
* **Catppuccin** themes by Catppuccin Org
* **Dracula** theme by Zeno Rocha
* **Espresso** theme by Sainnhe Park and Antoine Cotten
* **Everforest** themes by Sainnhe Park
* **Horizon** themes by Jonathan Olaleye
* **New Moon** theme by Tania Rascia
* **Noctis** themes by Liviu Schera and contributors
* **Nord** theme by Sven Greb
* **Owl** themes by Sarah Drasner
* **Primer** themes by GitHub, Inc. and Myian
* **Rosé Pine** themes by Rosé Pine
* **Snazzy Light** theme by Florian Reuschel
* **Solarized** themes by Ethan Schoonover
* **Tango** themes by the Tango Desktop Project
* **Tomorrow** themes by Chris Kempson

Other themes were created for novelWriter:

* **Aura Bright** theme by Myian
* **Blue Streak** themes by Veronica Berglyd Olsen
* **Castle** themes by Myian
* **Chalky Soil** theme by Myian
* **Chernozem** theme by Myian
* **Cyberpunk Night** theme by Anders Lemvigh
* **Floral** themes by Myian
* **Full Moon** theme by Myian
* **Jewel Case** themes by Myian
* **LCARS** theme by Veronica Berglyd Olsen
* **Nordlicht** theme by Myian
* **Otium** themes by Myian
* **Paragon** theme by Myian
* **Ruby** themes by Myian
* **Selenium** themes by Myian
* **Sepia** themes by Myian
* **Sultana** themes by Myian
* **Vivid** themes by Myian
* **Warpgate** theme by Myian
* **Waterlily** themes by Myian

## Fonts

The font used for the main novelWriter logo, mimetype and text banners is Pridi.

* **Pridi** by Cadson Demak (Open Font License, Version 1.1)

## Special Mentions

Additional thanks to John Blommers who was an early user and who has provided a lot of very useful
feedback over the years.
